var plplot__octaveOCTAVE__wrap_8cxx =
[
    [ "swig_type_info", "structswig__type__info.html", "structswig__type__info" ],
    [ "swig_cast_info", "structswig__cast__info.html", "structswig__cast__info" ],
    [ "swig_module_info", "structswig__module__info.html", "structswig__module__info" ],
    [ "swig_octave_member", "structswig__octave__member.html", "structswig__octave__member" ],
    [ "swig_octave_class", "structswig__octave__class.html", "structswig__octave__class" ],
    [ "octave_swig_type", "classoctave__swig__type.html", "classoctave__swig__type" ],
    [ "cpp_ptr", "structoctave__swig__type_1_1cpp__ptr.html", "structoctave__swig__type_1_1cpp__ptr" ],
    [ "octave_swig_ref", "classoctave__swig__ref.html", "classoctave__swig__ref" ],
    [ "octave_swig_packed", "classoctave__swig__packed.html", "classoctave__swig__packed" ],
    [ "octave_value_ref", "structoctave__value__ref.html", "structoctave__value__ref" ],
    [ "_SWIG_OCT_SEGF_HACK_ATEXIT_FCN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8719d3fa039deb7869ac4efd6a027c60", null ],
    [ "ComplexLU", "plplot__octaveOCTAVE__wrap_8cxx.html#a3f7a7992e99f3131e9f40ef943a87dd8", null ],
    [ "f2c", "plplot__octaveOCTAVE__wrap_8cxx.html#a1ffa0c2ac3e8935b915b4c2abd3e52d8", null ],
    [ "OCTAVE_API_VERSION_NUMBER", "plplot__octaveOCTAVE__wrap_8cxx.html#a1254fb4e5ab79f0fdb1edb9d6b387f58", null ],
    [ "Octave_Error_Occurred", "plplot__octaveOCTAVE__wrap_8cxx.html#aeef1c9b2220cc590521fe43f74bea0c9", null ],
    [ "SWIG_AddCast", "plplot__octaveOCTAVE__wrap_8cxx.html#ad69473581dbf2292673b61e56b35d893", null ],
    [ "SWIG_AddNewMask", "plplot__octaveOCTAVE__wrap_8cxx.html#af7ac7e424b623712f70e9b6640a54853", null ],
    [ "SWIG_AddTmpMask", "plplot__octaveOCTAVE__wrap_8cxx.html#af8527f0123949ec90e05d0fb156c11e3", null ],
    [ "SWIG_arg_fail", "plplot__octaveOCTAVE__wrap_8cxx.html#a01ff9379ead152cc27db42716b5aed9f", null ],
    [ "SWIG_ArgError", "plplot__octaveOCTAVE__wrap_8cxx.html#a95bab7504841595502bac5ed195becc1", null ],
    [ "SWIG_as_voidptr", "plplot__octaveOCTAVE__wrap_8cxx.html#a6dc8f6b962375bf647fc53ecbeca2d20", null ],
    [ "SWIG_as_voidptrptr", "plplot__octaveOCTAVE__wrap_8cxx.html#a46d91724837c8d2846b0b27f8bf1626c", null ],
    [ "SWIG_AttributeError", "plplot__octaveOCTAVE__wrap_8cxx.html#a5c83bd4d8f39d6eed1df7d3444caa2e1", null ],
    [ "SWIG_BADOBJ", "plplot__octaveOCTAVE__wrap_8cxx.html#a8268a243a8a840396db70f745c23c37c", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ad8a12a30aa976348f7fde7420c4d5e8e", null ],
    [ "SWIG_BUFFER_SIZE", "plplot__octaveOCTAVE__wrap_8cxx.html#a26324fcd1baceab72680dfec078da440", null ],
    [ "SWIG_CAST_NEW_MEMORY", "plplot__octaveOCTAVE__wrap_8cxx.html#ac8216459bfd45cbd2be36175ef6f1ccc", null ],
    [ "SWIG_CASTRANKLIMIT", "plplot__octaveOCTAVE__wrap_8cxx.html#a2f15c36f8b66185937b8232640be62e4", null ],
    [ "SWIG_CheckState", "plplot__octaveOCTAVE__wrap_8cxx.html#a1faed8ca17e98c961611bc35fde708a9", null ],
    [ "SWIG_contract_assert", "plplot__octaveOCTAVE__wrap_8cxx.html#aca11636b220cff70dac286c268c95ee6", null ],
    [ "SWIG_ConvertFunctionPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#a9a8ddc29a77ad0d18dc7d6ca55dd7f92", null ],
    [ "SWIG_ConvertMember", "plplot__octaveOCTAVE__wrap_8cxx.html#abb497a1b462ed19945a37c5cffb64de8", null ],
    [ "SWIG_ConvertPacked", "plplot__octaveOCTAVE__wrap_8cxx.html#a870d0838e4e08ed09cb8a5524e91bd56", null ],
    [ "SWIG_ConvertPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#a72b29226ccbfc8ab46f6247435daed44", null ],
    [ "SWIG_ConvertPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#a72b29226ccbfc8ab46f6247435daed44", null ],
    [ "SWIG_ConvertPtrAndOwn", "plplot__octaveOCTAVE__wrap_8cxx.html#acf0a954d9ffc3d37abfb95ab3a1639be", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7fad3d3926defa4614f8c3bd5e85fb50", null ],
    [ "SWIG_DelNewMask", "plplot__octaveOCTAVE__wrap_8cxx.html#ab3ead1d5cb36e1d79daf0bb4732957be", null ],
    [ "SWIG_DelTmpMask", "plplot__octaveOCTAVE__wrap_8cxx.html#ac08b44ea4ae9f73b19d915969f301a5d", null ],
    [ "SWIG_DivisionByZero", "plplot__octaveOCTAVE__wrap_8cxx.html#ae4cc0f5599402526dd5c2fdb80d87517", null ],
    [ "SWIG_ERROR", "plplot__octaveOCTAVE__wrap_8cxx.html#acfa11a770d66f9ca6ba170b173c56c94", null ],
    [ "SWIG_exception_fail", "plplot__octaveOCTAVE__wrap_8cxx.html#a567b84b185b0f14620c063787f998109", null ],
    [ "SWIG_fail", "plplot__octaveOCTAVE__wrap_8cxx.html#ababf56889b69e7a569556eb38cd4f157", null ],
    [ "SWIG_GetModule", "plplot__octaveOCTAVE__wrap_8cxx.html#ab97db3bbfc9e3a73de01e1ee95fa0bb5", null ],
    [ "SWIG_global_name", "plplot__octaveOCTAVE__wrap_8cxx.html#a0cd88c05992aac88a4bac44ae50d5520", null ],
    [ "SWIG_IndexError", "plplot__octaveOCTAVE__wrap_8cxx.html#af1ed73e454bdee28cc19369784f56eed", null ],
    [ "SWIG_IOError", "plplot__octaveOCTAVE__wrap_8cxx.html#a9fcdfcd79ad6f30120990223ea16879a", null ],
    [ "SWIG_IsNewObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a5246ae38052e6fa0e3cca2026cdda153", null ],
    [ "SWIG_IsOK", "plplot__octaveOCTAVE__wrap_8cxx.html#aea8ef410fde907633cb76d9d18131fa1", null ],
    [ "SWIG_IsTmpObj", "plplot__octaveOCTAVE__wrap_8cxx.html#aa8f2563a536468b40dc33843d4bb7efe", null ],
    [ "SWIG_MangledTypeQuery", "plplot__octaveOCTAVE__wrap_8cxx.html#a0ca9dc37d343186a34e966b5a8649ac0", null ],
    [ "SWIG_MemoryError", "plplot__octaveOCTAVE__wrap_8cxx.html#ae1cd9de0a75c6d814815a9de66a4a46d", null ],
    [ "SWIG_MODULE_CLIENTDATA_TYPE", "plplot__octaveOCTAVE__wrap_8cxx.html#a50d0a80dccc1d34749f07c82d6a04169", null ],
    [ "SWIG_name", "plplot__octaveOCTAVE__wrap_8cxx.html#acff905e8f0880e6e5bba1495c416a6af", null ],
    [ "SWIG_name_d", "plplot__octaveOCTAVE__wrap_8cxx.html#a51bd3fade0d8541deb41762a781956ec", null ],
    [ "SWIG_NewFunctionPtrObj", "plplot__octaveOCTAVE__wrap_8cxx.html#aab2f1993f97bd27040adf9836dafff18", null ],
    [ "SWIG_NewMemberObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a4b628289fae4cd1c4ee9be55e1927f65", null ],
    [ "SWIG_NEWOBJ", "plplot__octaveOCTAVE__wrap_8cxx.html#ab00ef4fde02a6d8d9653ea9edb28d3c9", null ],
    [ "SWIG_NEWOBJMASK", "plplot__octaveOCTAVE__wrap_8cxx.html#a0021b435c31c3ab285b5a6f4547719e3", null ],
    [ "SWIG_NewPackedObj", "plplot__octaveOCTAVE__wrap_8cxx.html#ab6d4285e098e13c5797188b2cf77592e", null ],
    [ "SWIG_NewPointerObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a978ff8eb5e32b08b8a1b8399c1994f23", null ],
    [ "SWIG_NullReferenceError", "plplot__octaveOCTAVE__wrap_8cxx.html#aa11fe417abd4c5a02d31cc1a51dee007", null ],
    [ "SWIG_OCT_SEGF_HACK_ATEXIT_FCN", "plplot__octaveOCTAVE__wrap_8cxx.html#af69c96a84916a335ccaa5c9da0907208", null ],
    [ "SWIG_Octave_AddErrorMsg", "plplot__octaveOCTAVE__wrap_8cxx.html#a074b6a028433944b362f531ee7a7fa5f", null ],
    [ "SWIG_Octave_ConvertPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#a059ec983f00a9ff600d30f35b72b1737", null ],
    [ "SWIG_OCTAVE_SEGFAULT_HACK", "plplot__octaveOCTAVE__wrap_8cxx.html#acd3193daa93921681446ad58453da13f", null ],
    [ "SWIG_OK", "plplot__octaveOCTAVE__wrap_8cxx.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7", null ],
    [ "SWIG_OLDOBJ", "plplot__octaveOCTAVE__wrap_8cxx.html#a4afcf490ff5b4abbca27ca23d9af288e", null ],
    [ "SWIG_op_prefix", "plplot__octaveOCTAVE__wrap_8cxx.html#a92d38f42f6f1e9aef0b57bd89a92d542", null ],
    [ "SWIG_OverflowError", "plplot__octaveOCTAVE__wrap_8cxx.html#ae9c11d011d8390489595f718d7565a8a", null ],
    [ "swig_owntype", "plplot__octaveOCTAVE__wrap_8cxx.html#ae8afee2b61d8b25aa291dc9574882369", null ],
    [ "SWIG_POINTER_DISOWN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa56139a289829795ed651d533826b65e", null ],
    [ "SWIG_POINTER_EXCEPTION", "plplot__octaveOCTAVE__wrap_8cxx.html#a1ad28578247a49297256a8d36c015f3f", null ],
    [ "SWIG_POINTER_OWN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1a125b0e9c551bb9cdeb21b8e5be5b57", null ],
    [ "SWIG_RUNTIME_VERSION", "plplot__octaveOCTAVE__wrap_8cxx.html#a4895907de5539551925ab5c03ea05d28", null ],
    [ "SWIG_RuntimeError", "plplot__octaveOCTAVE__wrap_8cxx.html#a34d3d1c1310427d00140bf1cc8de3ef6", null ],
    [ "SWIG_SetModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a673a7dcc5c15f5cffa7072785a6c7972", null ],
    [ "SWIG_SyntaxError", "plplot__octaveOCTAVE__wrap_8cxx.html#a1c4e29c043d3220cedca539360e07148", null ],
    [ "SWIG_SystemError", "plplot__octaveOCTAVE__wrap_8cxx.html#ae4a7b4ce78e031cbf5227bea38d81221", null ],
    [ "SWIG_TMPOBJ", "plplot__octaveOCTAVE__wrap_8cxx.html#ab1fe70ae34b39b709eb4cfb084862236", null ],
    [ "SWIG_TMPOBJMASK", "plplot__octaveOCTAVE__wrap_8cxx.html#a399dafc6302bd9b309041d5570ae94c9", null ],
    [ "SWIG_TYPE_TABLE_NAME", "plplot__octaveOCTAVE__wrap_8cxx.html#ac619a84edecccb5e00c1b4a3180b8c3a", null ],
    [ "SWIG_TypeError", "plplot__octaveOCTAVE__wrap_8cxx.html#a2685345a18f9d5fe8a390ec8500cb916", null ],
    [ "SWIG_TypeQuery", "plplot__octaveOCTAVE__wrap_8cxx.html#a184d005bbcde85bc7d3f652de20d10b3", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a3fe86959005f6ce39133b2db2cac0dec", null ],
    [ "SWIG_UnknownError", "plplot__octaveOCTAVE__wrap_8cxx.html#a45817cd389e6f40d0ffb004ff0678031", null ],
    [ "SWIG_ValueError", "plplot__octaveOCTAVE__wrap_8cxx.html#a4c1b15a2401d60351d98df9327886280", null ],
    [ "SWIG_VERSION", "plplot__octaveOCTAVE__wrap_8cxx.html#a8180a5d9a951bc3a9c5852fce5fde4e8", null ],
    [ "SWIGEXPORT", "plplot__octaveOCTAVE__wrap_8cxx.html#aea3c8b056dcc8c1ab93f6b825cd1371b", null ],
    [ "SWIGINLINE", "plplot__octaveOCTAVE__wrap_8cxx.html#a6d0a7c65b3712775e92c8bdb7acdd0ee", null ],
    [ "SWIGINTERN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f2319f775e5b9d5906c9ef25d9b819a", null ],
    [ "SWIGINTERNINLINE", "plplot__octaveOCTAVE__wrap_8cxx.html#afc5b08bb3c3cd2e3fb2e34b775346153", null ],
    [ "SWIGOCTAVE", "plplot__octaveOCTAVE__wrap_8cxx.html#ad6fb3697f46e722ef7dffdabeffcaf5b", null ],
    [ "swigreg_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a4515ab036c2b836726a1824ada77ffdf", null ],
    [ "swigreg_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a614956ae75cf02dc774786ebd69c165e", null ],
    [ "SWIGRUNTIME", "plplot__octaveOCTAVE__wrap_8cxx.html#a42cd9c1d67d803040a3e78515945afcb", null ],
    [ "SWIGRUNTIMEINLINE", "plplot__octaveOCTAVE__wrap_8cxx.html#affa7aa2bcce5bea24a20e5b184ae0533", null ],
    [ "SWIGSTDCALL", "plplot__octaveOCTAVE__wrap_8cxx.html#adcd6410456ea7a76147d3ad95b9bcb36", null ],
    [ "SWIGTEMPLATEDISAMBIGUATOR", "plplot__octaveOCTAVE__wrap_8cxx.html#a7e84031693895e512662f5b390c6d0e4", null ],
    [ "SWIGTYPE_p_char", "plplot__octaveOCTAVE__wrap_8cxx.html#a4fea528f7738d5fc0e2f14911d2b9d38", null ],
    [ "SWIGTYPE_p_double", "plplot__octaveOCTAVE__wrap_8cxx.html#ae614b9773454184a45966a0750727b9d", null ],
    [ "SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void", "plplot__octaveOCTAVE__wrap_8cxx.html#a48b31267a66347025b9c355ccfbd54a9", null ],
    [ "SWIGTYPE_p_f_int_double_p_char_int_p_void__void", "plplot__octaveOCTAVE__wrap_8cxx.html#ad7e79c86e7c871c2e72af2844fbf46d9", null ],
    [ "SWIGTYPE_p_f_int_p_double_p_double__void", "plplot__octaveOCTAVE__wrap_8cxx.html#ae94c3b6e426b2f10008f5a3c2f56af92", null ],
    [ "SWIGTYPE_p_int", "plplot__octaveOCTAVE__wrap_8cxx.html#a73413c3e668627181e90558738caccd5", null ],
    [ "SWIGTYPE_p_p_char", "plplot__octaveOCTAVE__wrap_8cxx.html#ae62a09763b43a6f895de430344a26b80", null ],
    [ "SWIGTYPE_p_PLGraphicsIn", "plplot__octaveOCTAVE__wrap_8cxx.html#a2a00b161b1ee44d933693f234ca003e5", null ],
    [ "SWIGTYPE_p_unsigned_int", "plplot__octaveOCTAVE__wrap_8cxx.html#ac97b19aa5dc7dde3dfd22b663edbca22", null ],
    [ "SWIGUNUSED", "plplot__octaveOCTAVE__wrap_8cxx.html#a6ee41cd160d397aa76668bf4db65e2d1", null ],
    [ "SWIGUNUSEDPARM", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a54164d0685c632e7540c5ad32a453a", null ],
    [ "SWIGVERSION", "plplot__octaveOCTAVE__wrap_8cxx.html#a82758940324a80fe482f130cc097c36e", null ],
    [ "ct_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a595f4b3960322d1991cb097ff49edb3f", null ],
    [ "defined_func", "plplot__octaveOCTAVE__wrap_8cxx.html#aead6f867c497426f7186863e3851644f", null ],
    [ "f2eval_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a5fe6f22b8e29a47aa53b073eadc90065", null ],
    [ "fill_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a18b05e8276c2f5a41addeea4dd595184", null ],
    [ "label_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a24e6529701ca8aa4bf683b08b8f8ca3c", null ],
    [ "mapform_func", "plplot__octaveOCTAVE__wrap_8cxx.html#aa6d42edeb63fc7047fe2a4b75171afaa", null ],
    [ "octave_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a31d42c9b8612a55f0f9b6d0ed6936c0c", null ],
    [ "pltr_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a3c135a6feccda3fdd1146327cab6c7a9", null ],
    [ "swig_cast_info", "plplot__octaveOCTAVE__wrap_8cxx.html#a9a04e6e78de723759e5450cd29429d1f", null ],
    [ "swig_converter_func", "plplot__octaveOCTAVE__wrap_8cxx.html#a2c314f22b391bfcaff5a11f4b76f66ec", null ],
    [ "swig_dycast_func", "plplot__octaveOCTAVE__wrap_8cxx.html#ad9f16e529633c78df7a780b9749395ce", null ],
    [ "swig_module_info", "plplot__octaveOCTAVE__wrap_8cxx.html#acf7d83901372902dd5cf59a611dfb320", null ],
    [ "swig_type_info", "plplot__octaveOCTAVE__wrap_8cxx.html#a838fee418372997705a565cd6ecd3b22", null ],
    [ "_arraylen", "plplot__octaveOCTAVE__wrap_8cxx.html#a3d06fcbf02e9ff89466acca8b9d24ef5", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#a1d65c2b7ea7957d605409180d98a154d", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#a9e2c1e63721dcfceb353ea66b0fe0fad", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#ab58362633ef06dbe0b64035610b5cdc2", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#aeb07bfd7786c0a8c910a0fb864d0c2ba", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#a5558f3855730d9e724b1500c9773c2d1", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#a1c4c9e64e95e4e5a2ab26cd251d9de05", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#a97e6a3c4217b94336c3e7e9e52dbd7d9", null ],
    [ "_cvt_double_to", "plplot__octaveOCTAVE__wrap_8cxx.html#ae2192678817b361f224496799fbb66d9", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a1fe13138a2b04ad14bd501d26f7db4b2", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a2c3e98f60e812dbdf3bc15289e954210", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a85dda6ad7496870b6aa175189ff28d24", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#ac868888ccecffbe3b1beda113f6d242d", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a9113e1077cf31507f1f02b5297ec8d92", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a7f6c8f25daa64c3bad3c38d9b475690f", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a575fc543a1bc0e14d1c90b08fbf9c675", null ],
    [ "_cvt_to_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a9cb169cc905477135b3e0ac252b6c955", null ],
    [ "_dim", "plplot__octaveOCTAVE__wrap_8cxx.html#a90dd94cafaecd69df1495d991317a545", null ],
    [ "_n_dims", "plplot__octaveOCTAVE__wrap_8cxx.html#a603c1e4a0233c47b62f6900f4e23b1c8", null ],
    [ "ct_octave", "plplot__octaveOCTAVE__wrap_8cxx.html#ae6d2a47dc41456407a6f5ae3cfceeaaa", null ],
    [ "DEFINE_OCTAVE_ALLOCATOR", "plplot__octaveOCTAVE__wrap_8cxx.html#a1c38bc0a81e9cac4e99cad1615434041", null ],
    [ "DEFINE_OCTAVE_ALLOCATOR", "plplot__octaveOCTAVE__wrap_8cxx.html#a621d8272de7916252c4a0565a86c2b43", null ],
    [ "DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA", "plplot__octaveOCTAVE__wrap_8cxx.html#ac4d8460f6574c9e8f5f170ef57c99814", null ],
    [ "DEFINE_OV_TYPEID_FUNCTIONS_AND_DATA", "plplot__octaveOCTAVE__wrap_8cxx.html#a4002b21652bb2b7c222e4a3968be9b27", null ],
    [ "DEFUN_DLD", "plplot__octaveOCTAVE__wrap_8cxx.html#ac13932b327fb71daa08748c18951c3f9", null ],
    [ "DEFUN_DLD", "plplot__octaveOCTAVE__wrap_8cxx.html#abbf0ebabef8311f62e7fae987a70b0fd", null ],
    [ "DEFUN_DLD", "plplot__octaveOCTAVE__wrap_8cxx.html#a1088cd965f29ad14aca570370afb8fd7", null ],
    [ "DEFUN_DLD", "plplot__octaveOCTAVE__wrap_8cxx.html#a41e892f26c71c2d1d444a693d46adcd7", null ],
    [ "DEFUN_DLD", "plplot__octaveOCTAVE__wrap_8cxx.html#af603dd8b1bc7c35c0f7d994edb96961f", null ],
    [ "labelfunc_octave", "plplot__octaveOCTAVE__wrap_8cxx.html#a89438106f388d4223b46dafd1661dfcc", null ],
    [ "mapform_octave", "plplot__octaveOCTAVE__wrap_8cxx.html#ae464aacef1988de30135ec954559f7ff", null ],
    [ "max", "plplot__octaveOCTAVE__wrap_8cxx.html#af082905f7eac6d03e92015146bbc1925", null ],
    [ "min", "plplot__octaveOCTAVE__wrap_8cxx.html#abd8bbcfabb3ddef2ccaafb9928a37b95", null ],
    [ "my_plcolorbar", "plplot__octaveOCTAVE__wrap_8cxx.html#a86bbf958622189fb14fcaefaddcd3056", null ],
    [ "my_plcont", "plplot__octaveOCTAVE__wrap_8cxx.html#aa974c1ed408faed8f0c2d36ccceb45bd", null ],
    [ "my_plcont0", "plplot__octaveOCTAVE__wrap_8cxx.html#a6e46d8bb1a69f33b7ab8f4b782fd606a", null ],
    [ "my_plcont1", "plplot__octaveOCTAVE__wrap_8cxx.html#a3af3958608d19874bae0e06788afe7b4", null ],
    [ "my_plcont2", "plplot__octaveOCTAVE__wrap_8cxx.html#ae119ab170706cc142db6817d72b903f0", null ],
    [ "my_plcont2p", "plplot__octaveOCTAVE__wrap_8cxx.html#aed7045f762a24f5e2c10e77352d95a20", null ],
    [ "my_plGetCursor", "plplot__octaveOCTAVE__wrap_8cxx.html#abb76f3993ce3844c3d0e92d1491d6960", null ],
    [ "my_plgriddata", "plplot__octaveOCTAVE__wrap_8cxx.html#a00d7f53f62ec46f7b758ec012c6011a7", null ],
    [ "my_plimage", "plplot__octaveOCTAVE__wrap_8cxx.html#a2be094a42ba2c826426e4cd81386aa2e", null ],
    [ "my_plimagefr", "plplot__octaveOCTAVE__wrap_8cxx.html#a49df986709fafc3f89a5b4877d163eba", null ],
    [ "my_plimagefr1", "plplot__octaveOCTAVE__wrap_8cxx.html#ae64139ae69f67362697ea57d1253b019", null ],
    [ "my_plimagefr2", "plplot__octaveOCTAVE__wrap_8cxx.html#a06ec66c5ebe681a05eaa2490aecb28e4", null ],
    [ "my_plimagefrx", "plplot__octaveOCTAVE__wrap_8cxx.html#a042982649b45e6ad1cf464c4d0c55fb5", null ],
    [ "my_plmesh", "plplot__octaveOCTAVE__wrap_8cxx.html#a298f8e686933a829c0bac6024a0cc272", null ],
    [ "my_plmeshc", "plplot__octaveOCTAVE__wrap_8cxx.html#afafd115d0d22ee71b78d010e10b06907", null ],
    [ "my_plot3d", "plplot__octaveOCTAVE__wrap_8cxx.html#a3bd433fbef9620928be1239d6e336db7", null ],
    [ "my_plot3dc", "plplot__octaveOCTAVE__wrap_8cxx.html#a0fdf54045b5f534b6f1c6e6687bfebf2", null ],
    [ "my_plot3dcl", "plplot__octaveOCTAVE__wrap_8cxx.html#a926158756d38e37c8ad3127127450dea", null ],
    [ "my_plshade", "plplot__octaveOCTAVE__wrap_8cxx.html#a74751aaf9648e124e4c18f8299cc9521", null ],
    [ "my_plshade1", "plplot__octaveOCTAVE__wrap_8cxx.html#adc1ee2e7cfe669412defcd120c18db1c", null ],
    [ "my_plshade2", "plplot__octaveOCTAVE__wrap_8cxx.html#aad280f1c356f1ba8b14a91a4c1200cca", null ],
    [ "my_plshades", "plplot__octaveOCTAVE__wrap_8cxx.html#ae6ffba314742354f7acd5f558847d10a", null ],
    [ "my_plshades1", "plplot__octaveOCTAVE__wrap_8cxx.html#a9bd595f4cd9fdba069f84d5d21108567", null ],
    [ "my_plshades2", "plplot__octaveOCTAVE__wrap_8cxx.html#a0de113614cd707237ae6f1c5dfe0683c", null ],
    [ "my_plshadesx", "plplot__octaveOCTAVE__wrap_8cxx.html#af0310d42321952432ed36fa39a25bc3a", null ],
    [ "my_plstripc", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f79ac9b2518d5c26de0fdade9955231", null ],
    [ "my_plsurf3d", "plplot__octaveOCTAVE__wrap_8cxx.html#a00481e018b10fd666ab7590b46d61b88", null ],
    [ "my_plsurf3dl", "plplot__octaveOCTAVE__wrap_8cxx.html#a25bb984a1821999f2eba97d9b98e42ee", null ],
    [ "my_plTranslateCursor", "plplot__octaveOCTAVE__wrap_8cxx.html#ae2c6c47ecc7535b19e73bb2df2dc2285", null ],
    [ "my_plvect", "plplot__octaveOCTAVE__wrap_8cxx.html#a6028faf7cc33c2bd903d432a6e826c13", null ],
    [ "my_plvect1", "plplot__octaveOCTAVE__wrap_8cxx.html#abfa806059bd7a31c788a248bd8d6ca40", null ],
    [ "my_plvect2", "plplot__octaveOCTAVE__wrap_8cxx.html#a7f0390bd9bd7bc7ba1aae4c502ae876a", null ],
    [ "octave_set_immutable", "plplot__octaveOCTAVE__wrap_8cxx.html#adf5ca0c253f8f1175ad6ec3198339e12", null ],
    [ "SWIG_AsCharArray", "plplot__octaveOCTAVE__wrap_8cxx.html#a94b7660d4d95ea8266bd8709795d6519", null ],
    [ "SWIG_AsCharPtrAndSize", "plplot__octaveOCTAVE__wrap_8cxx.html#a8039831f21f84a884d5f114b4645d3e9", null ],
    [ "SWIG_AsVal_char", "plplot__octaveOCTAVE__wrap_8cxx.html#a7195ae888b28a9fc16f3d423e603ca07", null ],
    [ "SWIG_AsVal_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a84148a94f7f31b8e1093e2ce3ea1a0d5", null ],
    [ "SWIG_AsVal_int", "plplot__octaveOCTAVE__wrap_8cxx.html#aa4ce87a1d64719206cf29bd20e2106b6", null ],
    [ "SWIG_AsVal_long", "plplot__octaveOCTAVE__wrap_8cxx.html#a13fdf94af38c992ad327edfe1e196ba8", null ],
    [ "SWIG_AsVal_unsigned_SS_int", "plplot__octaveOCTAVE__wrap_8cxx.html#a883e16a59f588df493b26c4c7d914d83", null ],
    [ "SWIG_AsVal_unsigned_SS_long", "plplot__octaveOCTAVE__wrap_8cxx.html#afb1901ab43f27535e220cc9160295f71", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a2840648a2d06ea4eca88274abe980381", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#adab4b2601c84280638fc4d73f228d697", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a0a735b46d48118b98b52f271873829b0", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a7342ce6a485fbd6736733c3dc83815eb", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ac3afefe3dc295fba272919560edb319e", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a48c6871d269048637406effe6911fb19", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a08dd8cad6d1d90dbda7a1c680bb9b488", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ae090fea98c5cdc9b3a7661bfc88c4315", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ae102cad8d4f9136065a5a03359283c1e", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a2e79bac78aae38223f11ce70e55577", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a5dfdd789e061858da13ec69fc35c7d9c", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#acae35bb196e7e2691d7cd05bfc18d896", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a7933009af7bfa6db45ba009a6c0b7c67", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a016a96bf5379211b89d1e2fdd5ec47bd", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a7265022f001c4dce61f560bece8c3e08", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#aafae648488f97db7dcb29aa81edde823", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a125fa474e4ae58f4482679b23dd6f2b3", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#aea573548ca6b31d69d332bc82ac4e663", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ae18db4e5bda90756c62d55326d801706", null ],
    [ "swig_binary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#affb66c4c6a1857f0af6a704c288ee6e2", null ],
    [ "SWIG_check_num_args", "plplot__octaveOCTAVE__wrap_8cxx.html#ac5984049b372c015bfe3abfbdb3d24a8", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a77a3f76cb1445325a013c2676f9c4581", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5734d9353408f1ae453b0385a02393e7", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac3a0c15e37d0b3f465a844dee154db26", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f11455ff62681657ca4c57d9d96863f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a2b39f891ef522830a1cf19b32de8e89a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a919017e3e2ca435ec52a256382f9ea70", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab7cab09a28ea264190e821629c691d34", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae5b3d9cdaa7af65ea5be352d761ae3ab", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a9c9957014a1ff7e47b4c50025ffeb47c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af70b181b46076ea7d5f53b7202740115", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a64cc39d295e1164b99b6efb87cf22fd6", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a218c9805383da4ed12220301f14f27eb", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a650b8da70b4f517ced7d17b7ff747c94", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a71637d28b53dc083423bd586bfec7822", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a18365b92f8c83681159759b0ce163207", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a06472d4b7e3ec0c57dc9e705d0ef4ade", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#abcff8cd901eedb5192c484c3eccb8421", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#addc35e21a73364c0e426b888c5327fb9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6e3bcd29255120af19fb2c33a1768c08", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aba57b582a1c7d882bf7d933cdc6f7b8c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3149b3bca7f590c0b2a3362ab4a2c2ec", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a647965de63f19cb1852c4aa05b614cd4", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a56eab964f5e45f34d41fa73ebb8d7a3a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a67d0f26b324f1725d58517e6858cb776", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa097e4949925663e5ef3fb3a091f8ee2", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a037c166c948a9116964aca68e80892b2", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a2621da255e2907e1352ddc8187764e7c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a9b420d3b542c4e80cb979d0bf45eff81", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad602a393d6b522dc765cf70be7414f90", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a417605959ef9861ccee7d30dd625d2e8", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a97e1ee7b9c83043f6be2b915c69a5ef7", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a5d7eb27df775891398e6f4b4d785f2", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adabf94e42ecd2cb74deb556bb7944e40", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a096e93af5dc22bd41def5f6ab0ef84c1", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adabf88e931783bcb037b3a7b2a02b69f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a80526bd463cf93db5afcb816f26ec11f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#acbdbe14d2faef06d1ca070250b738ccc", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ace7f1f67ff58617aa70186edf5134074", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8521e216ef802f50b10100b2fb981f35", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4f9b8bbdf6e8944871028e7ab69a0c00", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a31a9eaba8c7e13377428fb8b08535e4d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae687c274990d15e5b2e1484c145ae96f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a69febb06ef04eab0a9ae3fd4d6f61400", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a22e1555315a47708be8ff3e5d33c5f08", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab6072707e5ba7a4bb13e4ea730aa0c01", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5600b9e7ee12bea9a584e92fc421f44f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a2b42f9e7667ce6a96c31836e072e1f2f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af7b010dabb37db41a868a32ac97500e3", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5c6409a87e0bf2ddfc73a817958f52a5", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa637b72966d198a75e0c749b578c67b3", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a0827a88cbfeba3cfcbacd6bf1e696a2a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a928626f01cdb03e6e55f1e242bc155a3", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a7c77a8776d0b213fa561cd2da719bb", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aae20e9ebf61adaf08a670dc272506955", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab5d4f0eaaa3abe3565c7275d4bf777f3", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a415f8deb4f00abaf5fa52b38ff5613dd", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a0bf6b4b3ba2c111ce130e2a7f6187c8f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae4acc05214ac30664c05e16a7b638306", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a0d519f2303465fc84fbc8fb206e81117", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a9732eb25bd608c7596adedf0d25b9f62", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad1a59ac40bb9b11655787db2fcff31c9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a69a865d87bad543b01de2bedc74ab27d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a86d56f3f1fb6effb71a5ad8cdd91f577", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7874867fbba553f84c290815414ae03f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa8c88077d769deca3df9a66dfbf82627", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f0956f662917bda8d40d514634ad211", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7c3d4a414e9b6a4ae23be941012e940e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a827576f0fe439ec4eabfd4a98c749fac", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a689526bf32fe5ae1d8e2a4d08397ed4c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#acfaae3987a12e556d6236d5af4bd4aa4", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a24138a17d4f4e0d10f5bcb5f1614ba0a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac5f06121c94ba745921fc00150400369", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a53ca21ecb7ee9f500ea2e2b5c7feb49f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#acb37c74216a6f329da88db4224e26d71", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a26f0ad281f898c59f3b21c3ca19e9191", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6610b11ef8d369bbd6946dc359dd517e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad632aa81c10934a40f061e46892b771f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1feaef8cf5f9d182fedd14090a6e65a8", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7767ed70c351f9436878dbf3d36a82ed", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a86d5901889ede7d91ee0d8947a7f1267", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad7c08723e65ed556c356a1811ef013ca", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aba652dd5e72cb9b50e138afd5587235b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7a5e9e1492717fe9243a5a87666729bc", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac36f4ba34bd8e3e7be94776dbba42645", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5d97107521ab703a6e87deaefd9369b9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7097f3d479e450a7183416ed24f75f8d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6229308bede49ff4d87e36115212b7b9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a74624c855d594fa161d6ad66433094cb", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a37a20525d5da2914d762f422e53c2e13", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a95cd35d1c635cbec08a251efa0979890", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3e0f72f44d245bf8162ce0ba1b66fdc7", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae96d55a1265508b6fff4e7bc62df456d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a17fa29281f82db1ae00fce973c3a665e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6fc952f13c0856207d6dde3e8117212c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4ce59043e4908e9d399c4ce3063db487", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aaeadbe2ebf5c991850af56d75bc45fd4", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae9b1221c9577da8020f9e29cccb36e54", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a04e5eb9fe4e179531a6fe7d58fa58acf", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a57d4f983551b382522887e56fb6e5ee3", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aeddb4c7027221291e9162259edc10a51", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a066dcbffa058010ef349fe01c26dc25f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adada883e8e7acae3df4b65bb5acefd50", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a74a24aa3134d15fcd338aff25e380449", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a878f8aec325478c411eee8bd31e749ca", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aef8e06f612c958a8b1d118d6a00aeb2d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a659d8d30e1ea3ca956ddab57843fcff6", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad492f10da1dd5c15fec8853322bdced9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae00afa8554c4f0ad4027d40f333c2091", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a23ed661e5315095961dc85a0bb69990d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6decdb0b13fe7e7b90c89e0b9cc3b739", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4064de1783fcc6ffd405d38951985a7a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aae10b1f797b1cc62c67fd9726a3caa85", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a24d015ddf61f74104c2c582ef22fba30", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a60ff074289a9937105e23fc4d180bc58", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a82d80ea0a77abc302657309c651e3f68", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4752fab9823af6e76e8613cc2285fa82", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af2b755baee59a391f1f358d501d14ecb", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad2273610d98632dba1b7670ba5f7d27f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a552f8489e7947c37a6b6b3ca14d5db25", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4656c0abe51fb1e3e20901a5c589c2b6", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac9c71908e24b0c39c5b4c7f5e36183d9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a418963835f750400a3cafcd434eff960", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae1610a1661364aecf4cbae654af8311b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa0b31e0b4820e75dbfe6a3172703afd4", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8ba3e66a49b6738388dca099bb82f4f6", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a634ee5b99870159d6219e8b6ee2809ee", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aa445577078c6967c2d140f5a75bd7b6f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad255ea9bdc7510fa705e49d7f8e1eda4", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3e4b3ffbcd5310c1cbbdd019cb92d561", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a15169f6c0ee0e84d1f8a21879a42ca96", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a96d4325757a8f9f30b20ee632b88213a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4a08d0da87e3aee04ec857763b46ca5e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a815c41bb9d451bed2d153524ea642fba", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5031c0994fa584d6e6d76f20bc9e0f18", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f4c905f29d3f6eeb015cf1c6435dfc1", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a0ac2a123eb1c9eb73c0339bfd5e38e25", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab15cf39863c253ba7e8ec7bc010eb3f8", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a0c00d741df2b1f1b08dbb0f618fdf903", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad3f3ed577f8da03850a3d2f3dee7d06a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a53aa9b03a72b14fc88ecb3f29bdfaac6", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7dc68da70f0e5a3c27a19299a07611f2", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f4625af8e5c8339b0aadcc2e710e76b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a36b5263146c12be17fd68bc898eb977b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aff4aa2d15cfddd38056e259327e2ef95", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a63eb9c91855c305318c2651bb7ddf665", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a08ffa607a63874f1a17c8a4324885f25", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a85b837a5fc6b80ec172e547f2c51f703", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae9da335efb2b64c1fe2095a291721c54", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac7f5bcfd24ccfbd051d53e95eaa69714", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a76e8c5ad06b7d0f5168d01f5684610eb", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a240cada24f1b6a4abc16c28f07176aa4", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a06318313fdca800b34451662afb92784", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae8d855a04f9d287a57db8c8718886bda", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3f10c4a243c0303302473b0e1d0e8ab0", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae312d8a43892365fb372e4d1897f4c8d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3d68fca662b43d63675591b6a5bfd6a5", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ac9de73bd2fab83881bddbc9eb3b2379d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a0eafd2675009c12bd4ecf42ee8bc220c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af096816b0059b9628525373952e9715a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a11754a80ed33fbb0dbefec95fb847b59", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7cc1ed1d93d4f39d62dda956fe29a538", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3a80c431fcafad42f032a2e1b62e60a5", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4ea42eb5effb1db6292c0a7dacad5406", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f64239452bbea10519a8268d016ef9c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a86d639eef077499d196ad4a79b99c7ce", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab05cca03cda628ccf854882b6fc0edf8", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a997dc8151988fe670f50f8c35891bcaf", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae0b4d6745e9e6bf5b834275f7d819258", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a45917523bd0d3571c081ddc57e1e2fb7", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#add853fa696a3048cb7eae601ee248442", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4f79c306c74e28a67f0747668430f6ce", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af8675499e6b7e9f2eac955693412a217", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aca01ddd46314274631096fc136aed243", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1a85d4730cec30fc4bb7a4ad72a3b677", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab683a701faa872e8da59a01bc822a86c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a60bf394cfa84b257e7a013b93121ee30", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#acf1b58edd7d1b2da1fe265585e72a147", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aea3261f1f0ac5f56611b1880fb6b7040", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5a297903903b0043203733a1f742be41", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adcf7c230d8089fddffc57abd736a22f9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a073e32508c515e28d50d15b2413d4ff6", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a110926dd4553d95c291497ecd89b6503", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#aaad920dfbe901f64939bb9ac90368861", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a13566ed85b2333b4d4e483427d8ad9b9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a085853f5c390b0760e984bb7f829aa3a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a3fec2b61388b807f6872a4c5b928c02b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a33d71c7e8bfb89432e375f5e6020ef9c", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ae95f087c3087562dc226f74b75053fbe", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a51410046f19489d8db2581d6dc7b8e4a", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#acbafbc043714282ce64dc33fba0919fd", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a24261ad2bf1179dd54c3da1ba9aa6857", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ad29fd467771471a5291b05fb9d38b53f", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a232b2e24b1318c77c9638a3957b3de76", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a87287dca087c856ef1ebdfd3c9909b82", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a58040ec9ce7e80b81265e8fc2ac8a70e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a79dad026c4d38c3295353073ec66ab3b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4e4f2ee94e2f3ac59f9643125c446d83", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a8a11b9dde55e91b24f127871f8b5795d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a95e1afa4ab0addd2fc28d41601bcbe4d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a48b3fd7984ae94754243446a89e1ed83", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab7f3b92e5d73fc90f065b23e63dd5bf9", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a184f0559ac7ec110a52d14044f51ac7d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a641c1c9e8b7c80ff9f482249ef6cb4be", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a12cf024cd47038649f6cf6ea5a8876da", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a7fbe2055a28240472a78c503d2b4c13b", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4af5c41720a6128ce7215a878180b99e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#adad211784c1d5d6b490c3a3c23d58242", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a6f232a884088bcaaad9c23030bf4b91e", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a1cd8106ea5e2378845c7fa70b3381ac2", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a5c3bda0713d4efc775e20749adb08bcb", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#af6f2f0baaa9a67b48090977e550275a0", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a4b71efa6d36bcc28ea9a2bc1868d6bf8", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a68b4099adb55460808178a0baa9dda0d", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#a198bcd95151089c037a1787164218049", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ab0705c830dd24d8c9f9f79c9e90138fe", null ],
    [ "SWIG_DEFUN", "plplot__octaveOCTAVE__wrap_8cxx.html#ada6b73ba5d692c27e8625322c5e90212", null ],
    [ "SWIG_Error", "plplot__octaveOCTAVE__wrap_8cxx.html#af31149070bb121d50a353f0d4f901c86", null ],
    [ "SWIG_ErrorType", "plplot__octaveOCTAVE__wrap_8cxx.html#acb1c23171e087a7b9ba8bb1216a7b826", null ],
    [ "SWIG_From_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a40dfd41bc1e5bee7f8c57979ddbb397e", null ],
    [ "SWIG_From_int", "plplot__octaveOCTAVE__wrap_8cxx.html#a9fde9f53345db718fefe2715d1c9db91", null ],
    [ "SWIG_From_long", "plplot__octaveOCTAVE__wrap_8cxx.html#abf099221e1b33d4e94ac0ee332b97ff8", null ],
    [ "SWIG_From_unsigned_SS_int", "plplot__octaveOCTAVE__wrap_8cxx.html#affdef728dd1d3a1e6e233b1cc8ed7df1", null ],
    [ "SWIG_From_unsigned_SS_long", "plplot__octaveOCTAVE__wrap_8cxx.html#a846ff0c62d84b7501ba645b6c846c1e1", null ],
    [ "SWIG_FromCharPtrAndSize", "plplot__octaveOCTAVE__wrap_8cxx.html#a8c000dfd477fe68ba6bb164a3206152c", null ],
    [ "SWIG_init_user", "plplot__octaveOCTAVE__wrap_8cxx.html#a29869e3a769ac2b104bd19850e78c345", null ],
    [ "SWIG_InitializeModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a7f8da48fe4dbc23aef01a714623b8a6b", null ],
    [ "SWIG_InstallBinaryOps", "plplot__octaveOCTAVE__wrap_8cxx.html#a13dab8071049aa71567f6228ef64ce37", null ],
    [ "SWIG_InstallOps", "plplot__octaveOCTAVE__wrap_8cxx.html#ae441c428852d06ec6fe63cc6b3bcc5fd", null ],
    [ "SWIG_InstallUnaryOps", "plplot__octaveOCTAVE__wrap_8cxx.html#a179da016e9dc5705402cf3bf3e093c33", null ],
    [ "SWIG_MangledTypeQueryModule", "plplot__octaveOCTAVE__wrap_8cxx.html#ac63ad9b58a96793188f944c92ff40ec6", null ],
    [ "SWIG_name", "plplot__octaveOCTAVE__wrap_8cxx.html#a79097447f8af73de5d6567694270efe3", null ],
    [ "SWIG_Octave_AppendOutput", "plplot__octaveOCTAVE__wrap_8cxx.html#aa4e22e8ae30360485ff5feb73976b72c", null ],
    [ "SWIG_Octave_ConvertPacked", "plplot__octaveOCTAVE__wrap_8cxx.html#ae962d8a53602e6704dc9a9f58cad789a", null ],
    [ "SWIG_Octave_ConvertPtrAndOwn", "plplot__octaveOCTAVE__wrap_8cxx.html#a22bd0c6c9045fd5570cbd7b702463191", null ],
    [ "SWIG_Octave_GetGlobalValue", "plplot__octaveOCTAVE__wrap_8cxx.html#a42bb6b1a3ec055a7117bae65aa1a2ac5", null ],
    [ "SWIG_Octave_GetModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a9f1e2742a274869c13513a5382b1125e", null ],
    [ "SWIG_Octave_InstallFunction", "plplot__octaveOCTAVE__wrap_8cxx.html#a06f759762d8d2871dab7242714e791ad", null ],
    [ "SWIG_Octave_LinkGlobalValue", "plplot__octaveOCTAVE__wrap_8cxx.html#aa7aca5a9598d3a7e54a10c9ef913b551", null ],
    [ "SWIG_Octave_NewPackedObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a6178ee9c4a9a2bd28569fc00794fba30", null ],
    [ "SWIG_Octave_NewPointerObj", "plplot__octaveOCTAVE__wrap_8cxx.html#a6265b3fadf4a3e2b2cbb3bb207f80acb", null ],
    [ "SWIG_Octave_SetConstant", "plplot__octaveOCTAVE__wrap_8cxx.html#a8e8f2beeeb0aa3e404a0af39c30ab0ca", null ],
    [ "SWIG_Octave_SetGlobalValue", "plplot__octaveOCTAVE__wrap_8cxx.html#a0d0c1da95cd910c92d6cd5fe4b9abf7e", null ],
    [ "SWIG_Octave_SetModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a9cd1c69fc1037d2fa2385f33b4a0531b", null ],
    [ "SWIG_PackData", "plplot__octaveOCTAVE__wrap_8cxx.html#a02c2ac3db8ce87dd62813334e66c9a3a", null ],
    [ "SWIG_PackDataName", "plplot__octaveOCTAVE__wrap_8cxx.html#af903e6809a1fb2ba06deff49795c6e65", null ],
    [ "SWIG_PackVoidPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#a10c5572eb6206df7c95c8a2fcde90911", null ],
    [ "SWIG_pchar_descriptor", "plplot__octaveOCTAVE__wrap_8cxx.html#ae71b7c9eeb1f89aa554cb897ecef348f", null ],
    [ "SWIG_PropagateClientData", "plplot__octaveOCTAVE__wrap_8cxx.html#abc08944d526c952dc121d3d1b84f0d16", null ],
    [ "SWIG_TypeCast", "plplot__octaveOCTAVE__wrap_8cxx.html#a334486cb1e8f569c949a0384cbdb2a16", null ],
    [ "SWIG_TypeCheck", "plplot__octaveOCTAVE__wrap_8cxx.html#abd0cb78a9663e41312c8f14ab6715f04", null ],
    [ "SWIG_TypeCheckStruct", "plplot__octaveOCTAVE__wrap_8cxx.html#a898a1dfcdf96d53a2c7fd90e8500b36e", null ],
    [ "SWIG_TypeClientData", "plplot__octaveOCTAVE__wrap_8cxx.html#a4b0a40223812f7d43bc2f0c2342fe2f7", null ],
    [ "SWIG_TypeCompare", "plplot__octaveOCTAVE__wrap_8cxx.html#adc0e91b1eac793ed183ae989c62d33fb", null ],
    [ "SWIG_TypeDynamicCast", "plplot__octaveOCTAVE__wrap_8cxx.html#add8cb1a47628b36915ffa37d61452b1e", null ],
    [ "SWIG_TypeEquiv", "plplot__octaveOCTAVE__wrap_8cxx.html#a23ecf039d651082ffc7582c4f50af780", null ],
    [ "SWIG_TypeName", "plplot__octaveOCTAVE__wrap_8cxx.html#a68560e0bf641c9691704d6d05bac4358", null ],
    [ "SWIG_TypeNameComp", "plplot__octaveOCTAVE__wrap_8cxx.html#a2f69ad4207037cb391a2b2d5915fcba2", null ],
    [ "SWIG_TypeNewClientData", "plplot__octaveOCTAVE__wrap_8cxx.html#a710082a7ea6978d654bad712dbebc0ee", null ],
    [ "SWIG_TypePrettyName", "plplot__octaveOCTAVE__wrap_8cxx.html#a3f38ea686cb3f85bf6a15b08416f2684", null ],
    [ "SWIG_TypeQueryModule", "plplot__octaveOCTAVE__wrap_8cxx.html#a5b6a2719f95288678fa55ade4493b175", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ae2f3b18fc3f1a892cbc5240f5d954ee6", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a40d01b7e879d548d0d94834dcda4ae65", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a8f2db62c8575b1fa4e3f3f286638637f", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a43e45f69c19949dcddf0e7f339630076", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#ac01f770e58854f9e64964930b93f42b7", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a0d3d8d0c74fd473b9935fe0a05d5069b", null ],
    [ "swig_unary_op", "plplot__octaveOCTAVE__wrap_8cxx.html#a1ae7223c7353a451eeeeb505049ed480", null ],
    [ "SWIG_UnpackData", "plplot__octaveOCTAVE__wrap_8cxx.html#a80e9e66f66413297452de92c69cdf9d7", null ],
    [ "SWIG_UnpackDataName", "plplot__octaveOCTAVE__wrap_8cxx.html#a99540d89d9ffca957892cf22af3e49dd", null ],
    [ "SWIG_UnpackVoidPtr", "plplot__octaveOCTAVE__wrap_8cxx.html#ae3e13f3464cb74f7e5d9f7a50a6855c0", null ],
    [ "swig_value_deref", "plplot__octaveOCTAVE__wrap_8cxx.html#a3ce2e0045aa96bcb6fc78972ebd267c2", null ],
    [ "swig_value_deref", "plplot__octaveOCTAVE__wrap_8cxx.html#adfc0a276b8363d6147c668171787dbe2", null ],
    [ "swig_value_ref", "plplot__octaveOCTAVE__wrap_8cxx.html#ab3a5e1b0dc13df7f66ecc91e2c2eba4a", null ],
    [ "testppchar", "plplot__octaveOCTAVE__wrap_8cxx.html#a920477bad4bcedede7d93be4a1d1c513", null ],
    [ "xform", "plplot__octaveOCTAVE__wrap_8cxx.html#acf5309370447410efcc2382acbb597cc", null ],
    [ "_swigc__p_char", "plplot__octaveOCTAVE__wrap_8cxx.html#a8848127146fe0444e2fe3183a15b67f5", null ],
    [ "_swigc__p_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a28b7f0e03111f37524cf093e3a8a2304", null ],
    [ "_swigc__p_f_double_double_p_double_p_double_p_void__void", "plplot__octaveOCTAVE__wrap_8cxx.html#a3f4c37068cdd295d0dafa913f043216e", null ],
    [ "_swigc__p_f_int_double_p_char_int_p_void__void", "plplot__octaveOCTAVE__wrap_8cxx.html#abd7eee4930f48e2326a9df35e20f0bba", null ],
    [ "_swigc__p_f_int_p_double_p_double__void", "plplot__octaveOCTAVE__wrap_8cxx.html#a5c2379fb009e6c97a5de4731c20e4283", null ],
    [ "_swigc__p_int", "plplot__octaveOCTAVE__wrap_8cxx.html#a216d8b24b856092e2e65830ef290159b", null ],
    [ "_swigc__p_p_char", "plplot__octaveOCTAVE__wrap_8cxx.html#adf82b09513b48dd2275acc2fa74711b7", null ],
    [ "_swigc__p_PLGraphicsIn", "plplot__octaveOCTAVE__wrap_8cxx.html#adbc9470f42e7e3c0a2adab2df09b950d", null ],
    [ "_swigc__p_unsigned_int", "plplot__octaveOCTAVE__wrap_8cxx.html#aba9e61dc970ecfa60bf8a90276b1daa9", null ],
    [ "_swigt__p_char", "plplot__octaveOCTAVE__wrap_8cxx.html#ae66f44191f70db7b9634a8321766c840", null ],
    [ "_swigt__p_double", "plplot__octaveOCTAVE__wrap_8cxx.html#a650096f8d16b87549437da125768b407", null ],
    [ "_swigt__p_f_double_double_p_double_p_double_p_void__void", "plplot__octaveOCTAVE__wrap_8cxx.html#a169d330528354eea0e80046288f7a240", null ],
    [ "_swigt__p_f_int_double_p_char_int_p_void__void", "plplot__octaveOCTAVE__wrap_8cxx.html#ad192a829bb4110f62a13c396ab965321", null ],
    [ "_swigt__p_f_int_p_double_p_double__void", "plplot__octaveOCTAVE__wrap_8cxx.html#ac93b2bfcffa54c72401ce0fe924336ef", null ],
    [ "_swigt__p_int", "plplot__octaveOCTAVE__wrap_8cxx.html#abb18e7711ddb7deeaf40f89dd6643b2c", null ],
    [ "_swigt__p_p_char", "plplot__octaveOCTAVE__wrap_8cxx.html#a701773c68706ee07319dc186a10ec151", null ],
    [ "_swigt__p_PLGraphicsIn", "plplot__octaveOCTAVE__wrap_8cxx.html#aa7423ef65fc1e3d9cc8e9acb90b31531", null ],
    [ "_swigt__p_unsigned_int", "plplot__octaveOCTAVE__wrap_8cxx.html#ac758895aa5c2bb2a384d76af7fc77b2c", null ],
    [ "_wrap_class_PLGraphicsIn", "plplot__octaveOCTAVE__wrap_8cxx.html#ab1150b7ebddb76d9e0884b3300ef4edd", null ],
    [ "_wrap_pl_setcontlabelformat_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a76edcc2158f8896af1584385985b7baa", null ],
    [ "_wrap_pl_setcontlabelparam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7d69e72e6fa91ee737d5b6f20af8bc4a", null ],
    [ "_wrap_pladv_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a0930e7ca7a2b3564c5c9c604eaec6799", null ],
    [ "_wrap_plarc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a3554ac4d6122a21636f13e1b80d54c61", null ],
    [ "_wrap_plaxes_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a65dd1b401de58c03f4bc7124f914579d", null ],
    [ "_wrap_plbin_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a22bea9a6b4dffb3f31bfdef626e3f00c", null ],
    [ "_wrap_plbop_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae5c0ac10e2630787663c19ee546f6bc5", null ],
    [ "_wrap_plbox3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a03cfd966415718f4fffecb9193d53b41", null ],
    [ "_wrap_plbox_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab853cfe7ce775d3882971390e4584627", null ],
    [ "_wrap_plbtime_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5b30d9dc4ea6486f01114cbc1de0126b", null ],
    [ "_wrap_plcalc_world_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a0a2c258f6dcd3cdf6513734422990176", null ],
    [ "_wrap_plclear_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ac5c6e7b86c86dc0737dac02df648b105", null ],
    [ "_wrap_plcol0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1761de57100c0d31a25fb0f2b1d89004", null ],
    [ "_wrap_plcol1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aeec4aea06c98bb36d5625d3f903fe485", null ],
    [ "_wrap_plcolorbar_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afab0eefbdde0ae7077e59fc76995ac71", null ],
    [ "_wrap_plconfigtime_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7216a1ee562155fabc49e88fdd64746c", null ],
    [ "_wrap_plcont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aeb5e286e22dd49a5c53d06e3e0d49913", null ],
    [ "_wrap_plcpstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a83a26a27ebfa2aba10d7710d34d5dbef", null ],
    [ "_wrap_plctime_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aec230e51536ce9702385accbe5d43823", null ],
    [ "_wrap_plend1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a37ce505d80c4ed872fcc4634362e344a", null ],
    [ "_wrap_plend_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a12b6a75136ddfbc0b72065f15381c86f", null ],
    [ "_wrap_plenv0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a44c4b472eadb4005011215b1c2fee6dc", null ],
    [ "_wrap_plenv_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4645cc4e3a33879ba6c841dc073d5d47", null ],
    [ "_wrap_pleop_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab5fb59ba5c25d13808a7d038cffc1a77", null ],
    [ "_wrap_plerrx_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f3b1d55b43a0cc5aabf458c26d3c641", null ],
    [ "_wrap_plerry_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#af8c15263209289b0773cd78380263f1d", null ],
    [ "_wrap_plfamadv_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a178609368d50ddbbf167108ef7ae23d6", null ],
    [ "_wrap_plfill3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab13b34305802ebe00f7d04cac290f626", null ],
    [ "_wrap_plfill_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a2c6311c6b5b14d92c71fd956ed2019d9", null ],
    [ "_wrap_plflush_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1c92f63eaba5d356a9351507ddabb963", null ],
    [ "_wrap_plfont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad28e38730730fd3fdb27e7c360fed5a5", null ],
    [ "_wrap_plfontld_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a79d9f72aeda3ed9642cd42ccff4eadd8", null ],
    [ "_wrap_plgchr_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4f2bcefca98606b5697148b740127ce6", null ],
    [ "_wrap_plgcmap1_range_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a353b601cfe71ab0e29c3426679437ed3", null ],
    [ "_wrap_plgcol0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9356bc1d7e75b8b4e89eeed4e9837b06", null ],
    [ "_wrap_plgcol0a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a33ff8a9ce80ad074a212665248b43359", null ],
    [ "_wrap_plgcolbg_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad59523ca68afcfbf0139250017683a37", null ],
    [ "_wrap_plgcolbga_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a3864274b76f1cfdbffdfed55c44fdba0", null ],
    [ "_wrap_plgcompression_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a2b95f19b0d4d9ddabac884ae34d484c1", null ],
    [ "_wrap_plgdev_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1714980fbc94d3d0899550854c1d4d27", null ],
    [ "_wrap_plgdidev_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ade375d0038cb6f2024a244e0ecd34ff0", null ],
    [ "_wrap_plgdiori_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a58b681a2e82a2a4b6abed90d18e7cfe2", null ],
    [ "_wrap_plgdiplt_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a81af5d9d150d7f45682f903e3f0bb1a2", null ],
    [ "_wrap_plgfam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5dbd9d3f9accae4a39c873006db5a504", null ],
    [ "_wrap_plgfci_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9f4997b65360e1bb8940cf15e8cdb3d7", null ],
    [ "_wrap_plgfnam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a448e50f9abb019758b9cb1b64c95f335", null ],
    [ "_wrap_plgfont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a68c9310ea86620c6eb342fed30f0732d", null ],
    [ "_wrap_plglevel_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a999fb467b38d42930630c1283b35e7c3", null ],
    [ "_wrap_plgpage_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a3cb56c1e02dd0a800320bb3ae92b95e0", null ],
    [ "_wrap_plgra_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae9edd6bffb84c56c14b227b54cee149d", null ],
    [ "_wrap_plgradient_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afc8bbf76f9aed0216a7dc7e73d2556d7", null ],
    [ "_wrap_plgriddata_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ac0192a83fc06dbecaf696b811eba49c1", null ],
    [ "_wrap_plgspa_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad6c1830b23066ec1272e75a6da3e32e3", null ],
    [ "_wrap_plgstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7198af1b4b98936047474e5f9f9a85aa", null ],
    [ "_wrap_plgver_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a531eb694c170e1674dcaa9993e649de8", null ],
    [ "_wrap_plgvpd_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa40eeba571a52c1d722072f4dcc52cce", null ],
    [ "_wrap_plgvpw_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6817eac6c54e9236624357ee3d5ecf63", null ],
    [ "_wrap_plgxax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a77cd39a79393cb74c8ee81fb518571fe", null ],
    [ "_wrap_plgyax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab7ff8eece1983c1346b546d727c534ac", null ],
    [ "_wrap_plgzax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a730dc323aa59640537133acd57cff60d", null ],
    [ "_wrap_plhist_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aea461967543b0664b4f8e47740e9df46", null ],
    [ "_wrap_plhlsrgb_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa236c6bec1399905d39e8576ee4d6916", null ],
    [ "_wrap_plimagefr_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aced4dd5e41a58f1d126a0332d4179cef", null ],
    [ "_wrap_plinit_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7975d40886664c1c53d41fdedf449100", null ],
    [ "_wrap_pljoin_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad07a9c4fcac378014e82375a664f6961", null ],
    [ "_wrap_pllab_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab9cde54baf0c8d14ca631917658a63e2", null ],
    [ "_wrap_pllegend_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa09b24d0f8cd0f15548d833395b67b80", null ],
    [ "_wrap_pllightsource_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a2f2b0548e3a20888a7a71eea0a42c0a8", null ],
    [ "_wrap_plline3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad81af41f841a15e9f5582bfe13622031", null ],
    [ "_wrap_plline_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a73ac1d462f6994ffbd1a6f29aeecea44", null ],
    [ "_wrap_pllsty_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a705e6d891cc869a85e78ae597f6304eb", null ],
    [ "_wrap_plmap_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a61485d75cd2c7bf96f766343011586a5", null ],
    [ "_wrap_plmapfill_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a653c01bc6b35fb020c1db2c8aa85c223", null ],
    [ "_wrap_plmapline_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7c2b14e1e4bb6e5ec4faa64df9c4112b", null ],
    [ "_wrap_plmapstring_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a47e9a99e16ac455df40cd578a3abdfa1", null ],
    [ "_wrap_plmaptex_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#adb7310118f8750ab8cc0b6c73de0f209", null ],
    [ "_wrap_plmeridians_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1a8b540981e35670894f9eda38d00967", null ],
    [ "_wrap_plmesh_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6387ee3c522f6fde37faac6ef9f67f9b", null ],
    [ "_wrap_plmeshc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a05986bd52600fc7e2d9896a1faa890a6", null ],
    [ "_wrap_plmkstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a0c447aec75278270bc33c5b4af2f4546", null ],
    [ "_wrap_plmtex3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa53274e1db64febf0e9201f075116861", null ],
    [ "_wrap_plmtex_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6132d587658e5f9b5d686120e71b569a", null ],
    [ "_wrap_plot3d_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a608b9473b4442fcf49fd460d7f9179c4", null ],
    [ "_wrap_plot3dc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a20c13f074fc6d38461de38d80311afef", null ],
    [ "_wrap_plot3dcl_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad4b812626f9f2fcbebd472fc2793c384", null ],
    [ "_wrap_plparseopts_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad50938b99012a96743156299e0bf21b8", null ],
    [ "_wrap_plpat_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad6de6f229517ee07ee9bc2f783db6f03", null ],
    [ "_wrap_plpath_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#accf0b523c4d903538d61bfd6edda9091", null ],
    [ "_wrap_plpoin3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a79cf81937918fa9edea3e124c3e84bb3", null ],
    [ "_wrap_plpoin_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#abd1be9beb88110e4bcd4e36dee608301", null ],
    [ "_wrap_plpoly3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae041b99e6db05f04a39001f1a4282932", null ],
    [ "_wrap_plprec_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a3afd5038121b836cb51b40623b43f7b9", null ],
    [ "_wrap_plpsty_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7b67e923c010c0a60ed0d9e0eda8683e", null ],
    [ "_wrap_plptex3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab1a29aadbc3eb3d90b5e5e52a3ac2321", null ],
    [ "_wrap_plptex_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a214c716a8eb03ca28cd1daa656a51650", null ],
    [ "_wrap_plrandd_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a637e1bd31a2440ddae06f76d7c03c871", null ],
    [ "_wrap_plreplot_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#af6ef84d78c14a04745d3a73715d97a6f", null ],
    [ "_wrap_plrgbhls_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6296bb6a836e3cf7673bc8533cf6846b", null ],
    [ "_wrap_plschr_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a3cf50e8e8b15f005e72e05c189ffd28e", null ],
    [ "_wrap_plscmap0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a32e7f636b575d4a19d94cf97bc3fa16f", null ],
    [ "_wrap_plscmap0a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aead5dc1d59867f1a441bafa41c05cc28", null ],
    [ "_wrap_plscmap0n_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a65f48f537cc71a859d911ce533414569", null ],
    [ "_wrap_plscmap1_range_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#afea08d524a1f34fc96f67b61079b4bfb", null ],
    [ "_wrap_plscmap1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a03cf65f0151e6b99793a43192b292470", null ],
    [ "_wrap_plscmap1a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a8b6dc3c0af9c5fa2f654962909cd1d7e", null ],
    [ "_wrap_plscmap1l_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aad41a3e50d11416b50ffcb5cccc1582c", null ],
    [ "_wrap_plscmap1la_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae59ee61cf3dfd15c8ed257e871b2fb39", null ],
    [ "_wrap_plscmap1n_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a3b745ab3c969de372e15b8cbda7f1e", null ],
    [ "_wrap_plscol0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7db49bb07b4ef90aa3f0e991d467a69f", null ],
    [ "_wrap_plscol0a_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a891d46c37c7b12726c698a71f28c2788", null ],
    [ "_wrap_plscolbg_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aed30ba9ab3b78b5b77ec6cd1571ae947", null ],
    [ "_wrap_plscolbga_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a8906c0dc597f0f81a1cbb13c7e92109c", null ],
    [ "_wrap_plscolor_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a2ba823335dd55140feb81ab76093b7ea", null ],
    [ "_wrap_plscompression_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7d35dc8f3883c79dbf9608d7e4345135", null ],
    [ "_wrap_plsdev_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a775a1e3c7bf76df65906edb49e52b1a8", null ],
    [ "_wrap_plsdidev_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1c1f9e5264d87cc251d5e4617c5f07e3", null ],
    [ "_wrap_plsdimap_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#abc9a6a743a4f72a3c7647df61094180c", null ],
    [ "_wrap_plsdiori_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a40ba5378f7ecd0a77edfa5c396cc2cbd", null ],
    [ "_wrap_plsdiplt_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a50749520e44c84e0ef9ef1afa9b1bea4", null ],
    [ "_wrap_plsdiplz_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6f2ed4442f119283aab6ea36998125e8", null ],
    [ "_wrap_plseed_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5e2de7b0b9ccbe5be14689a94e377864", null ],
    [ "_wrap_plsesc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a67025781d17c02eb767767b652502182", null ],
    [ "_wrap_plSetOpt_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a34164819ab4f46b57e27a35310a9ecda", null ],
    [ "_wrap_plsfam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a52a50d1946285172f140211bba09a0ed", null ],
    [ "_wrap_plsfci_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4c3dcc40198bd902387211e9e20e62d7", null ],
    [ "_wrap_plsfnam_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a1f9dfda765c853242b80ce0b909bd171", null ],
    [ "_wrap_plsfont_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a9fd95438850d30290a2696b0772d0943", null ],
    [ "_wrap_plshade1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a56e6bbe3f1b66306773901d7a6a33901", null ],
    [ "_wrap_plshade_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a758878c62155eddc4ed09be54c46e585", null ],
    [ "_wrap_plshades_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a69ba285128deca5a9e650bb24066d5d6", null ],
    [ "_wrap_plslabelfunc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a4bf96847a6ca31044b2aaf3d1fc73ed2", null ],
    [ "_wrap_plsmaj_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a26597a107bb38cbd32f14a1c046d4d52", null ],
    [ "_wrap_plsmin_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a98f1de558a442b07859ded8fa6e75326", null ],
    [ "_wrap_plsori_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a505b76871e2dccf9a9676c8758a8718b", null ],
    [ "_wrap_plspage_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#abb55eca59339b3713433b1f1819e1366", null ],
    [ "_wrap_plspal0_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ac1963b0e515643598e09298ce61c240d", null ],
    [ "_wrap_plspal1_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aea94f71ceea2a14cfcafb14bf2caa5a6", null ],
    [ "_wrap_plspause_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#abe99d015803bfe4e1572f467a353bcab", null ],
    [ "_wrap_plsstrm_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a26cdfdf16086bb01ae0d51fee969151d", null ],
    [ "_wrap_plssub_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a72998008cbd4608cb473bdde61c5477a", null ],
    [ "_wrap_plssym_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae6f1473af2fda478ead3cdcc4589fb05", null ],
    [ "_wrap_plstar_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a94885ccc9f3eadf8f7ad961c17276ab3", null ],
    [ "_wrap_plstart_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a7d7e2eaf3d543753b1141048c633712b", null ],
    [ "_wrap_plstransform_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5432d1e2f43bbc46b1a16b0315a28c61", null ],
    [ "_wrap_plstring3_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a01915eb364f5a2a95916ca8119109fe8", null ],
    [ "_wrap_plstring_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#adc68738aa382c25d57692734b32a2b9f", null ],
    [ "_wrap_plstripa_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad36ed9784b616cd56c2ba9776ae43a1d", null ],
    [ "_wrap_plstripc_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a5caf9bb5f1ed7b311d939b522a017110", null ],
    [ "_wrap_plstripd_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a504a917ad44d08564b5997a62de04a63", null ],
    [ "_wrap_plstyl_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6a4cd8420161832b90cbdba4a3533fa2", null ],
    [ "_wrap_plsurf3d_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a438a8ffdceab1a2e877ad3fb0615f84b", null ],
    [ "_wrap_plsurf3dl_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a63c84c9795f5f74f3e4cb372d9cd5176", null ],
    [ "_wrap_plsvect_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#af878cbcf61bf72976099a3399ba9b3ed", null ],
    [ "_wrap_plsvpa_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a13530096b73487b7ce2c59c202c9e813", null ],
    [ "_wrap_plsxax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#aa501592638bfa257b89ecef6f6887068", null ],
    [ "_wrap_plsyax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#abc65beba588f31dc5a89c412114e63fe", null ],
    [ "_wrap_plsym_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a47130cee7b868a8868f0dd3d3ff864c5", null ],
    [ "_wrap_plszax_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a00dedeeeecb76b07d977c39073cfa7a7", null ],
    [ "_wrap_pltext_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ab734671e68f7032000f6c7e4850f7702", null ],
    [ "_wrap_pltimefmt_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a121d640a5966d8f1aa6fd19ddc7c5f22", null ],
    [ "_wrap_plvasp_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae2f058e059af4134c502a7184eb2a3c4", null ],
    [ "_wrap_plvect_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a84f771c2d9c077a0eea911b1b1478a99", null ],
    [ "_wrap_plvpas_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a070f675ffbc42d40983ac0c3fb62af28", null ],
    [ "_wrap_plvpor_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a99d9ee043452c923b369ed08f16431e5", null ],
    [ "_wrap_plvsta_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a03917336709886d45c374df975694c86", null ],
    [ "_wrap_plw3d_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ae47738aaf075f83fed969c04cc6ea14b", null ],
    [ "_wrap_plwidth_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#ad1d01421c97390b60b7563a7de79d1d9", null ],
    [ "_wrap_plwind_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#a6ab5777aa4e65311f6f4cea99a621fcf", null ],
    [ "_wrap_plxormod_texinfo", "plplot__octaveOCTAVE__wrap_8cxx.html#acc2cdf6cc5b73e76054e0eeb883995d4", null ],
    [ "Alen", "plplot__octaveOCTAVE__wrap_8cxx.html#a27d25ac7e864031d461a8a5460144223", null ],
    [ "fcnCoordTrans", "plplot__octaveOCTAVE__wrap_8cxx.html#a155f6008b033b8b13bc7ead36da93c6e", null ],
    [ "fcnLabelFunc", "plplot__octaveOCTAVE__wrap_8cxx.html#a9dc9722fd122f685f600c847d96992d4", null ],
    [ "fcnMapForm", "plplot__octaveOCTAVE__wrap_8cxx.html#ab35fb75236326f44a50a302d85f5f72c", null ],
    [ "nameCoordTrans", "plplot__octaveOCTAVE__wrap_8cxx.html#a33f1c985bad67f8e20add9c8be5e4cc8", null ],
    [ "nameLabelFunc", "plplot__octaveOCTAVE__wrap_8cxx.html#a7c348614501dedaba8f040b2281cb7e1", null ],
    [ "nameMapForm", "plplot__octaveOCTAVE__wrap_8cxx.html#a55952eae0c718eb31b7692a0db8957c5", null ],
    [ "subclass_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#a70e41eebfacedae630ffb0f6830da98d", null ],
    [ "swig_cast_initial", "plplot__octaveOCTAVE__wrap_8cxx.html#a0666e347f7d486a3bc82b78efd732333", null ],
    [ "swig_globals", "plplot__octaveOCTAVE__wrap_8cxx.html#a78ba4a1a89f3ec642716ba1cdbb414b6", null ],
    [ "swig_module", "plplot__octaveOCTAVE__wrap_8cxx.html#a5f41f6e106d3195e660a39e5292f50fd", null ],
    [ "SWIG_name_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#a3be459f147c734c484303f9ca2e95fd5", null ],
    [ "swig_PLGraphicsIn_base", "plplot__octaveOCTAVE__wrap_8cxx.html#a131d0e3556f9b6d6929bcc035e4decf5", null ],
    [ "swig_PLGraphicsIn_base_names", "plplot__octaveOCTAVE__wrap_8cxx.html#a61ee77e649c977070ca543d7c915c4dd", null ],
    [ "swig_PLGraphicsIn_members", "plplot__octaveOCTAVE__wrap_8cxx.html#ad3a05f9995d8c5088c40028b1f1dfd7b", null ],
    [ "swig_this_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#ade4b7dfe74b1deb042e21c0cb9335f84", null ],
    [ "swig_type_initial", "plplot__octaveOCTAVE__wrap_8cxx.html#ad621c8a05a43cf3a48467c791142bb44", null ],
    [ "swig_type_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#a74bda2c13e54a9066ddaef85f389a5a8", null ],
    [ "swig_typequery_usage", "plplot__octaveOCTAVE__wrap_8cxx.html#a334ee93af44aca1d08e52dee7590938d", null ],
    [ "swig_types", "plplot__octaveOCTAVE__wrap_8cxx.html#a0f20ac04d873220b9386f47abb3b6981", null ],
    [ "Xlen", "plplot__octaveOCTAVE__wrap_8cxx.html#ac91c25f032882cfbd3e877adb9dd788d", null ],
    [ "Ylen", "plplot__octaveOCTAVE__wrap_8cxx.html#a63da9b8b39f2bb3fdf520fdc1dd0870a", null ]
];